use image::{DynamicImage, GenericImageView};
use image::imageops::FilterType;

use crate::config::image_processors::ProcessorParams;
use crate::result::MBGResult;

pub struct ScaleProcessor {
    pub params: ProcessorParams,
    pub screen_height: i32,
    pub screen_width: i32,
}

impl super::ImageProcessor for ScaleProcessor {
    fn process(&self, img: &DynamicImage) -> MBGResult<DynamicImage> {
        let abs_width = self.screen_width.abs() as u32;
        let scale_factor = (abs_width as f32 / img.width() as f32) * self.params.strength;
        debug!("Scaling image by {} times", scale_factor);
        Ok(img.resize(
            (img.width() as f32 * scale_factor) as u32,
            (img.height() as f32 * scale_factor) as u32,
            FilterType::Nearest,
        ))
    }
}
